Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(382)

Unified Diff: chrome/browser/thumbnails/thumbnail_service_factory.h

Issue 15517005: Remove references to Profile from browser_context_keyed_service. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/thumbnails/thumbnail_service_factory.h
diff --git a/chrome/browser/thumbnails/thumbnail_service_factory.h b/chrome/browser/thumbnails/thumbnail_service_factory.h
index 655cfa68d9ff2dbbdc3fe76765941fac28d75aa5..23f529bfc751d6134c218fed486cdb034b8538b7 100644
--- a/chrome/browser/thumbnails/thumbnail_service_factory.h
+++ b/chrome/browser/thumbnails/thumbnail_service_factory.h
@@ -15,14 +15,14 @@ namespace thumbnails {
class ThumbnailService;
}
-class ThumbnailServiceFactory : public RefcountedProfileKeyedServiceFactory {
+class ThumbnailServiceFactory : public RefcountedBrowserContextKeyedServiceFactory {
public:
// Returns an instance of ThumbnailService associated with this profile
// (creating one if none exists). Returns NULL if this profile cannot have a
// ThumbnailService (for example, if |profile| is incognito).
// Depending on the settings, the implementation of the service interface
// can be provided either by TopSites (stored in the profile itself) or
// be an instance of a real RefcountedProfileKeyedService implementation.
static scoped_refptr<thumbnails::ThumbnailService> GetForProfile(
Profile* profile);
@@ -34,8 +34,8 @@ class ThumbnailServiceFactory : public RefcountedProfileKeyedServiceFactory {
ThumbnailServiceFactory();
virtual ~ThumbnailServiceFactory();
- // ProfileKeyedServiceFactory:
- virtual scoped_refptr<RefcountedProfileKeyedService> BuildServiceInstanceFor(
+ // BrowserContextKeyedServiceFactory:
+ virtual scoped_refptr<RefcountedBrowserContextKeyedService> BuildServiceInstanceFor(
content::BrowserContext* profile) const OVERRIDE;
DISALLOW_COPY_AND_ASSIGN(ThumbnailServiceFactory);
@@ -15,14 +15,14 @@ namespace thumbnails {
// Depending on the settings, the implementation of the service interface
// can be provided either by TopSites (stored in the profile itself) or
- // be an instance of a real RefcountedProfileKeyedService implementation.
+ // be an instance of a real RefcountedBrowserContextKeyedService implementation.
static scoped_refptr<thumbnails::ThumbnailService> GetForProfile(
Profile* profile);

Powered by Google App Engine
This is Rietveld 408576698